Class: Aws::SWF::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SWF::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-swf/client.rb,
sig/client.rbs
Overview
An API client for SWF. To construct a client, you need to configure a :region and :credentials.
client = Aws::SWF::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CountClosedWorkflowExecutionsResponseSuccess, _CountOpenWorkflowExecutionsResponseSuccess, _CountPendingActivityTasksResponseSuccess, _CountPendingDecisionTasksResponseSuccess, _DescribeActivityTypeResponseSuccess, _DescribeDomainResponseSuccess, _DescribeWorkflowExecutionResponseSuccess, _DescribeWorkflowTypeResponseSuccess, _GetWorkflowExecutionHistoryResponseSuccess, _ListActivityTypesResponseSuccess, _ListClosedWorkflowExecutionsResponseSuccess, _ListDomainsResponseSuccess, _ListOpenWorkflowExecutionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkflowTypesResponseSuccess, _PollForActivityTaskResponseSuccess, _PollForDecisionTaskResponseSuccess, _RecordActivityTaskHeartbeatResponseSuccess, _StartWorkflowExecutionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#count_closed_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionCount
Returns the number of closed workflow executions within the given domain that meet the specified filtering criteria.
-
#count_open_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionCount
Returns the number of open workflow executions within the given domain that meet the specified filtering criteria.
-
#count_pending_activity_tasks(params = {}) ⇒ Types::PendingTaskCount
Returns the estimated number of activity tasks in the specified task list.
-
#count_pending_decision_tasks(params = {}) ⇒ Types::PendingTaskCount
Returns the estimated number of decision tasks in the specified task list.
-
#delete_activity_type(params = {}) ⇒ Struct
Deletes the specified activity type.
-
#delete_workflow_type(params = {}) ⇒ Struct
Deletes the specified workflow type.
-
#deprecate_activity_type(params = {}) ⇒ Struct
Deprecates the specified activity type.
-
#deprecate_domain(params = {}) ⇒ Struct
Deprecates the specified domain.
-
#deprecate_workflow_type(params = {}) ⇒ Struct
Deprecates the specified workflow type.
-
#describe_activity_type(params = {}) ⇒ Types::ActivityTypeDetail
Returns information about the specified activity type.
-
#describe_domain(params = {}) ⇒ Types::DomainDetail
Returns information about the specified domain, including description and status.
-
#describe_workflow_execution(params = {}) ⇒ Types::WorkflowExecutionDetail
Returns information about the specified workflow execution including its type and some statistics.
-
#describe_workflow_type(params = {}) ⇒ Types::WorkflowTypeDetail
Returns information about the specified workflow type.
-
#get_workflow_execution_history(params = {}) ⇒ Types::History
Returns the history of the specified workflow execution.
-
#list_activity_types(params = {}) ⇒ Types::ActivityTypeInfos
Returns information about all activities registered in the specified domain that match the specified name and registration status.
-
#list_closed_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionInfos
Returns a list of closed workflow executions in the specified domain that meet the filtering criteria.
-
#list_domains(params = {}) ⇒ Types::DomainInfos
Returns the list of domains registered in the account.
-
#list_open_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionInfos
Returns a list of open workflow executions in the specified domain that meet the filtering criteria.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List tags for a given domain.
-
#list_workflow_types(params = {}) ⇒ Types::WorkflowTypeInfos
Returns information about workflow types in the specified domain.
-
#poll_for_activity_task(params = {}) ⇒ Types::ActivityTask
Used by workers to get an ActivityTask from the specified activity
taskList. -
#poll_for_decision_task(params = {}) ⇒ Types::DecisionTask
Used by deciders to get a DecisionTask from the specified decision
taskList. -
#record_activity_task_heartbeat(params = {}) ⇒ Types::ActivityTaskStatus
Used by activity workers to report to the service that the ActivityTask represented by the specified
taskTokenis still making progress. -
#register_activity_type(params = {}) ⇒ Struct
Registers a new activity type along with its configuration settings in the specified domain.
-
#register_domain(params = {}) ⇒ Struct
Registers a new domain.
-
#register_workflow_type(params = {}) ⇒ Struct
Registers a new workflow type and its configuration settings in the specified domain.
-
#request_cancel_workflow_execution(params = {}) ⇒ Struct
Records a
WorkflowExecutionCancelRequestedevent in the currently running workflow execution identified by the given domain, workflowId, and runId. -
#respond_activity_task_canceled(params = {}) ⇒ Struct
Used by workers to tell the service that the ActivityTask identified by the
taskTokenwas successfully canceled. -
#respond_activity_task_completed(params = {}) ⇒ Struct
Used by workers to tell the service that the ActivityTask identified by the
taskTokencompleted successfully with aresult(if provided). -
#respond_activity_task_failed(params = {}) ⇒ Struct
Used by workers to tell the service that the ActivityTask identified by the
taskTokenhas failed withreason(if specified). -
#respond_decision_task_completed(params = {}) ⇒ Struct
Used by deciders to tell the service that the DecisionTask identified by the
taskTokenhas successfully completed. -
#signal_workflow_execution(params = {}) ⇒ Struct
Records a
WorkflowExecutionSignaledevent in the workflow execution history and creates a decision task for the workflow execution identified by the given domain, workflowId and runId. -
#start_workflow_execution(params = {}) ⇒ Types::Run
Starts an execution of the workflow type in the specified domain using the provided
workflowIdand input data. -
#tag_resource(params = {}) ⇒ Struct
Add a tag to a Amazon SWF domain.
-
#terminate_workflow_execution(params = {}) ⇒ Struct
Records a
WorkflowExecutionTerminatedevent and forces closure of the workflow execution identified by the given domain, runId, and workflowId. -
#undeprecate_activity_type(params = {}) ⇒ Struct
Undeprecates a previously deprecated activity type.
-
#undeprecate_domain(params = {}) ⇒ Struct
Undeprecates a previously deprecated domain.
-
#undeprecate_workflow_type(params = {}) ⇒ Struct
Undeprecates a previously deprecated workflow type.
-
#untag_resource(params = {}) ⇒ Struct
Remove a tag from a Amazon SWF domain.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-swf/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4609 4610 4611 |
# File 'lib/aws-sdk-swf/client.rb', line 4609 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4612 4613 4614 |
# File 'lib/aws-sdk-swf/client.rb', line 4612 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 |
# File 'lib/aws-sdk-swf/client.rb', line 4582 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SWF') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-swf' context[:gem_version] = '1.89.0' Seahorse::Client::Request.new(handlers, context) end |
#count_closed_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionCount
Returns the number of closed workflow executions within the given domain that meet the specified filtering criteria.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
tagFilter.tag: String constraint. The key isswf:tagFilter.tag. -
typeFilter.name: String constraint. The key isswf:typeFilter.name. -
typeFilter.version: String constraint. The key isswf:typeFilter.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
88 |
# File 'sig/client.rbs', line 88
def count_closed_workflow_executions: (
|
#count_open_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionCount
Returns the number of open workflow executions within the given domain that meet the specified filtering criteria.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
tagFilter.tag: String constraint. The key isswf:tagFilter.tag. -
typeFilter.name: String constraint. The key isswf:typeFilter.name. -
typeFilter.version: String constraint. The key isswf:typeFilter.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
120 |
# File 'sig/client.rbs', line 120
def count_open_workflow_executions: (
|
#count_pending_activity_tasks(params = {}) ⇒ Types::PendingTaskCount
Returns the estimated number of activity tasks in the specified task
list. The count returned is an approximation and isn't guaranteed to
be exact. If you specify a task list that no activity task was ever
scheduled in then 0 is returned.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the
taskList.nameparameter by using aConditionelement with theswf:taskList.namekey to allow the action to access only certain task lists.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
145 |
# File 'sig/client.rbs', line 145
def count_pending_activity_tasks: (
|
#count_pending_decision_tasks(params = {}) ⇒ Types::PendingTaskCount
Returns the estimated number of decision tasks in the specified task
list. The count returned is an approximation and isn't guaranteed to
be exact. If you specify a task list that no decision task was ever
scheduled in then 0 is returned.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the
taskList.nameparameter by using aConditionelement with theswf:taskList.namekey to allow the action to access only certain task lists.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
159 |
# File 'sig/client.rbs', line 159
def count_pending_decision_tasks: (
|
#delete_activity_type(params = {}) ⇒ Struct
Deletes the specified activity type.
Note: Prior to deletion, activity types must first be deprecated.
After an activity type has been deleted, you cannot schedule new activities of that type. Activities that started before the type was deleted will continue to run.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
activityType.name: String constraint. The key isswf:activityType.name. -
activityType.version: String constraint. The key isswf:activityType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
168 |
# File 'sig/client.rbs', line 168
def delete_activity_type: (
|
#delete_workflow_type(params = {}) ⇒ Struct
Deletes the specified workflow type.
Note: Prior to deletion, workflow types must first be deprecated.
After a workflow type has been deleted, you cannot create new executions of that type. Executions that started before the type was deleted will continue to run.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
178 |
# File 'sig/client.rbs', line 178
def delete_workflow_type: (
|
#deprecate_activity_type(params = {}) ⇒ Struct
Deprecates the specified activity type. After an activity type has been deprecated, you cannot create new tasks of that activity type. Tasks of this type that were scheduled before the type was deprecated continue to run.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
activityType.name: String constraint. The key isswf:activityType.name. -
activityType.version: String constraint. The key isswf:activityType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
188 |
# File 'sig/client.rbs', line 188
def deprecate_activity_type: (
|
#deprecate_domain(params = {}) ⇒ Struct
Deprecates the specified domain. After a domain has been deprecated it cannot be used to create new workflow executions or register new types. However, you can still use visibility actions on this domain. Deprecating a domain also deprecates all activity and workflow types registered in the domain. Executions that were started before the domain was deprecated continues to run.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
198 |
# File 'sig/client.rbs', line 198
def deprecate_domain: (
|
#deprecate_workflow_type(params = {}) ⇒ Struct
Deprecates the specified workflow type. After a workflow type has been deprecated, you cannot create new executions of that type. Executions that were started before the type was deprecated continues to run. A deprecated workflow type may still be used when calling visibility actions.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
204 |
# File 'sig/client.rbs', line 204
def deprecate_workflow_type: (
|
#describe_activity_type(params = {}) ⇒ Types::ActivityTypeDetail
Returns information about the specified activity type. This includes configuration settings provided when the type was registered and other general information about the type.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
activityType.name: String constraint. The key isswf:activityType.name. -
activityType.version: String constraint. The key isswf:activityType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
219 |
# File 'sig/client.rbs', line 219
def describe_activity_type: (
|
#describe_domain(params = {}) ⇒ Types::DomainDetail
Returns information about the specified domain, including description and status.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
234 |
# File 'sig/client.rbs', line 234
def describe_domain: (
|
#describe_workflow_execution(params = {}) ⇒ Types::WorkflowExecutionDetail
Returns information about the specified workflow execution including its type and some statistics.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
248 |
# File 'sig/client.rbs', line 248
def describe_workflow_execution: (
|
#describe_workflow_type(params = {}) ⇒ Types::WorkflowTypeDetail
Returns information about the specified workflow type. This includes configuration settings specified when the type was registered and other information such as creation date, current status, etc.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
263 |
# File 'sig/client.rbs', line 263
def describe_workflow_type: (
|
#get_workflow_execution_history(params = {}) ⇒ Types::History
Returns the history of the specified workflow execution. The results
may be split into multiple pages. To retrieve subsequent pages, make
the call again using the nextPageToken returned by the initial call.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
278 |
# File 'sig/client.rbs', line 278
def get_workflow_execution_history: (
|
#list_activity_types(params = {}) ⇒ Types::ActivityTypeInfos
Returns information about all activities registered in the specified
domain that match the specified name and registration status. The
result includes information like creation date, current status of the
activity, etc. The results may be split into multiple pages. To
retrieve subsequent pages, make the call again using the
nextPageToken returned by the initial call.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
296 |
# File 'sig/client.rbs', line 296
def list_activity_types: (
|
#list_closed_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionInfos
Returns a list of closed workflow executions in the specified domain that meet the filtering criteria. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
tagFilter.tag: String constraint. The key isswf:tagFilter.tag. -
typeFilter.name: String constraint. The key isswf:typeFilter.name. -
typeFilter.version: String constraint. The key isswf:typeFilter.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
312 |
# File 'sig/client.rbs', line 312
def list_closed_workflow_executions: (
|
#list_domains(params = {}) ⇒ Types::DomainInfos
Returns the list of domains registered in the account. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. The element must be set toarn:aws:swf::AccountID:domain/*, where AccountID is the account ID, with no dashes. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
347 |
# File 'sig/client.rbs', line 347
def list_domains: (
|
#list_open_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionInfos
Returns a list of open workflow executions in the specified domain that meet the filtering criteria. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
tagFilter.tag: String constraint. The key isswf:tagFilter.tag. -
typeFilter.name: String constraint. The key isswf:typeFilter.name. -
typeFilter.version: String constraint. The key isswf:typeFilter.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
361 |
# File 'sig/client.rbs', line 361
def list_open_workflow_executions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
List tags for a given domain.
388 |
# File 'sig/client.rbs', line 388
def list_tags_for_resource: (
|
#list_workflow_types(params = {}) ⇒ Types::WorkflowTypeInfos
Returns information about workflow types in the specified domain. The results may be split into multiple pages that can be retrieved by making the call repeatedly.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
399 |
# File 'sig/client.rbs', line 399
def list_workflow_types: (
|
#poll_for_activity_task(params = {}) ⇒ Types::ActivityTask
Used by workers to get an ActivityTask from the specified activity
taskList. This initiates a long poll, where the service holds the
HTTP connection open and responds as soon as a task becomes available.
The maximum time the service holds on to the request before responding
is 60 seconds. If no task is available within 60 seconds, the poll
returns an empty result. An empty result, in this context, means that
an ActivityTask is returned, but that the value of taskToken is an
empty string. If a task is returned, the worker should use its type to
identify and process it correctly.
Workers should set their client side socket timeout to at least 70 seconds (10 seconds higher than the maximum time service may hold the poll request).
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the
taskList.nameparameter by using aConditionelement with theswf:taskList.namekey to allow the action to access only certain task lists.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
419 |
# File 'sig/client.rbs', line 419
def poll_for_activity_task: (
|
#poll_for_decision_task(params = {}) ⇒ Types::DecisionTask
Used by deciders to get a DecisionTask from the specified decision
taskList. A decision task may be returned for any open workflow
execution that is using the specified task list. The task includes a
paginated view of the history of the workflow execution. The decider
should use the workflow type and the history to determine how to
properly handle the task.
This action initiates a long poll, where the service holds the HTTP connection open and responds as soon a task becomes available. If no decision task is available in the specified task list before the timeout of 60 seconds expires, an empty result is returned. An empty result, in this context, means that a DecisionTask is returned, but that the value of taskToken is an empty string.
Deciders should set their client side socket timeout to at least 70 seconds (10 seconds higher than the timeout).
Because the number of workflow history events for a single workflow
execution might be very large, the result returned might be split up
across a number of pages. To retrieve subsequent pages, make
additional calls to PollForDecisionTask using the nextPageToken
returned by the initial call. Note that you do not call
GetWorkflowExecutionHistory with this nextPageToken. Instead, call
PollForDecisionTask again.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the
taskList.nameparameter by using aConditionelement with theswf:taskList.namekey to allow the action to access only certain task lists.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
439 |
# File 'sig/client.rbs', line 439
def poll_for_decision_task: (
|
#record_activity_task_heartbeat(params = {}) ⇒ Types::ActivityTaskStatus
Used by activity workers to report to the service that the
ActivityTask represented by the specified taskToken is still making
progress. The worker can also specify details of the progress, for
example percent complete, using the details parameter. This action
can also be used by the worker as a mechanism to check if cancellation
is being requested for the activity task. If a cancellation is being
attempted for the specified task, then the boolean cancelRequested
flag returned by the service is set to true.
This action resets the taskHeartbeatTimeout clock. The
taskHeartbeatTimeout is specified in RegisterActivityType.
This action doesn't in itself create an event in the workflow
execution history. However, if the task times out, the workflow
execution history contains a ActivityTaskTimedOut event that
contains the information from the last heartbeat generated by the
activity worker.
taskStartToCloseTimeout of an activity type is the maximum
duration of an activity task, regardless of the number of
RecordActivityTaskHeartbeat requests received. The
taskStartToCloseTimeout is also specified in RegisterActivityType.
If the cancelRequested flag returns true, a cancellation is being
attempted. If the worker can cancel the activity, it should respond
with RespondActivityTaskCanceled. Otherwise, it should ignore the
cancellation request.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
457 |
# File 'sig/client.rbs', line 457
def record_activity_task_heartbeat: (
|
#register_activity_type(params = {}) ⇒ Struct
Registers a new activity type along with its configuration settings in the specified domain.
A TypeAlreadyExists fault is returned if the type already exists in
the domain. You cannot change any configuration settings of the type
after its registration, and it must be registered as a new version.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
defaultTaskList.name: String constraint. The key isswf:defaultTaskList.name. -
name: String constraint. The key isswf:name. -
version: String constraint. The key isswf:version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
464 |
# File 'sig/client.rbs', line 464
def register_activity_type: (
|
#register_domain(params = {}) ⇒ Struct
Registers a new domain.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
You cannot use an IAM policy to control domain access for this action. The name of the domain being registered is available as the resource of this action.
-
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
481 |
# File 'sig/client.rbs', line 481
def register_domain: (
|
#register_workflow_type(params = {}) ⇒ Struct
Registers a new workflow type and its configuration settings in the specified domain.
The retention period for the workflow history is set by the RegisterDomain action.
If the type already exists, then a TypeAlreadyExists fault is
returned. You cannot change the configuration settings of a workflow
type once it is registered and it must be registered as a new version.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
defaultTaskList.name: String constraint. The key isswf:defaultTaskList.name. -
name: String constraint. The key isswf:name. -
version: String constraint. The key isswf:version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
495 |
# File 'sig/client.rbs', line 495
def register_workflow_type: (
|
#request_cancel_workflow_execution(params = {}) ⇒ Struct
Records a WorkflowExecutionCancelRequested event in the currently
running workflow execution identified by the given domain, workflowId,
and runId. This logically requests the cancellation of the workflow
execution as a whole. It is up to the decider to take appropriate
actions when it receives an execution history with this event.
WorkflowExecutionCancelRequested
event is recorded in the history of the current open workflow
execution with the specified workflowId in the domain.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
512 |
# File 'sig/client.rbs', line 512
def request_cancel_workflow_execution: (
|
#respond_activity_task_canceled(params = {}) ⇒ Struct
Used by workers to tell the service that the ActivityTask identified
by the taskToken was successfully canceled. Additional details can
be provided using the details argument.
These details (if provided) appear in the ActivityTaskCanceled
event added to the workflow history.
Only use this operation if the canceled flag of a
RecordActivityTaskHeartbeat request returns true and if the activity
can be safely undone or abandoned.
A task is considered open from the time that it is scheduled until it is closed. Therefore a task is reported as open while a worker is processing it. A task is closed after it has been specified in a call to RespondActivityTaskCompleted, RespondActivityTaskCanceled, RespondActivityTaskFailed, or the task has timed out.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
520 |
# File 'sig/client.rbs', line 520
def respond_activity_task_canceled: (
|
#respond_activity_task_completed(params = {}) ⇒ Struct
Used by workers to tell the service that the ActivityTask identified
by the taskToken completed successfully with a result (if
provided). The result appears in the ActivityTaskCompleted event
in the workflow history.
If the requested task doesn't complete successfully, use
RespondActivityTaskFailed instead. If the worker finds that the task
is canceled through the canceled flag returned by
RecordActivityTaskHeartbeat, it should cancel the task, clean up and
then call RespondActivityTaskCanceled.
A task is considered open from the time that it is scheduled until it is closed. Therefore a task is reported as open while a worker is processing it. A task is closed after it has been specified in a call to RespondActivityTaskCompleted, RespondActivityTaskCanceled, RespondActivityTaskFailed, or the task has timed out.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
527 |
# File 'sig/client.rbs', line 527
def respond_activity_task_completed: (
|
#respond_activity_task_failed(params = {}) ⇒ Struct
Used by workers to tell the service that the ActivityTask identified
by the taskToken has failed with reason (if specified). The
reason and details appear in the ActivityTaskFailed event added
to the workflow history.
A task is considered open from the time that it is scheduled until it is closed. Therefore a task is reported as open while a worker is processing it. A task is closed after it has been specified in a call to RespondActivityTaskCompleted, RespondActivityTaskCanceled, RespondActivityTaskFailed, or the task has timed out.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
534 |
# File 'sig/client.rbs', line 534
def respond_activity_task_failed: (
|
#respond_decision_task_completed(params = {}) ⇒ Struct
Used by deciders to tell the service that the DecisionTask identified
by the taskToken has successfully completed. The decisions
argument specifies the list of decisions made while processing the
task.
A DecisionTaskCompleted event is added to the workflow history. The
executionContext specified is attached to the event in the workflow
execution history.
Access Control
If an IAM policy grants permission to use
RespondDecisionTaskCompleted, it can express permissions for the
list of decisions in the decisions parameter. Each of the decisions
has one or more parameters, much like a regular API call. To allow for
policies to be as readable as possible, you can express permissions on
decisions as if they were actual API calls, including applying
conditions to some parameters. For more information, see Using IAM to
Manage Access to Amazon SWF Workflows in the Amazon SWF Developer
Guide.
542 |
# File 'sig/client.rbs', line 542
def respond_decision_task_completed: (
|
#signal_workflow_execution(params = {}) ⇒ Struct
Records a WorkflowExecutionSignaled event in the workflow execution
history and creates a decision task for the workflow execution
identified by the given domain, workflowId and runId. The event is
recorded with the specified user defined signalName and input (if
provided).
WorkflowExecutionSignaled
event is recorded in the history of the current open workflow with the
matching workflowId in the domain.
UnknownResource.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
650 |
# File 'sig/client.rbs', line 650
def signal_workflow_execution: (
|
#start_workflow_execution(params = {}) ⇒ Types::Run
Starts an execution of the workflow type in the specified domain using
the provided workflowId and input data.
This action returns the newly started workflow execution.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
tagList.member.0: The key isswf:tagList.member.0. -
tagList.member.1: The key isswf:tagList.member.1. -
tagList.member.2: The key isswf:tagList.member.2. -
tagList.member.3: The key isswf:tagList.member.3. -
tagList.member.4: The key isswf:tagList.member.4. -
taskList: String constraint. The key isswf:taskList.name. -
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
664 |
# File 'sig/client.rbs', line 664
def start_workflow_execution: (
|
#tag_resource(params = {}) ⇒ Struct
Add a tag to a Amazon SWF domain.
685 |
# File 'sig/client.rbs', line 685
def tag_resource: (
|
#terminate_workflow_execution(params = {}) ⇒ Struct
Records a WorkflowExecutionTerminated event and forces closure of
the workflow execution identified by the given domain, runId, and
workflowId. The child policy, registered with the workflow type or
specified when starting this execution, is applied to any open child
workflow executions of this workflow execution.
If the identified workflow execution was in progress, it is terminated immediately.
WorkflowExecutionTerminated
event is recorded in the history of the current open workflow with the
matching workflowId in the domain.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
697 |
# File 'sig/client.rbs', line 697
def terminate_workflow_execution: (
|
#undeprecate_activity_type(params = {}) ⇒ Struct
Undeprecates a previously deprecated activity type. After an activity type has been undeprecated, you can create new tasks of that activity type.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
activityType.name: String constraint. The key isswf:activityType.name. -
activityType.version: String constraint. The key isswf:activityType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
708 |
# File 'sig/client.rbs', line 708
def undeprecate_activity_type: (
|
#undeprecate_domain(params = {}) ⇒ Struct
Undeprecates a previously deprecated domain. After a domain has been undeprecated it can be used to create new workflow executions or register new types.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
You cannot use an IAM policy to constrain this action's parameters.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
718 |
# File 'sig/client.rbs', line 718
def undeprecate_domain: (
|
#undeprecate_workflow_type(params = {}) ⇒ Struct
Undeprecates a previously deprecated workflow type. After a workflow type has been undeprecated, you can create new executions of that type.
Access Control
You can use IAM policies to control this action's access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys. -
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
If the caller doesn't have sufficient permissions to invoke the
action, or the parameter values fall outside the specified
constraints, the action fails. The associated event attribute's
cause parameter is set to OPERATION_NOT_PERMITTED. For details and
example IAM policies, see Using IAM to Manage Access to Amazon SWF
Workflows in the Amazon SWF Developer Guide.
724 |
# File 'sig/client.rbs', line 724
def undeprecate_workflow_type: (
|
#untag_resource(params = {}) ⇒ Struct
Remove a tag from a Amazon SWF domain.
734 |
# File 'sig/client.rbs', line 734
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4602 4603 4604 |
# File 'lib/aws-sdk-swf/client.rb', line 4602 def waiter_names [] end |