Method: Aws::SWF::Client#count_open_workflow_executions

Defined in:
lib/aws-sdk-swf/client.rb

#count_open_workflow_executions(params = {}) ⇒ Types::WorkflowExecutionCount

Returns the number of open workflow executions within the given domain that meet the specified filtering criteria.

<note markdown=“1”> This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.

</note>

**Access Control**

You can use IAM policies to control this action’s access to Amazon SWF resources as follows:

  • Use a Resource element with the domain name to limit the action to only specified domains.

  • Use an Action element to allow or deny permission to call this action.

  • Constrain the following parameters by using a Condition element with the appropriate keys.

    • tagFilter.tag: String constraint. The key is swf:tagFilter.tag.

    • typeFilter.name: String constraint. The key is swf:typeFilter.name.

    • typeFilter.version: String constraint. The key is swf:typeFilter.version.

If the caller doesn’t have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute’s cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF Workflows] in the *Amazon SWF Developer Guide*.

[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html

Examples:

Request syntax with placeholder values


resp = client.count_open_workflow_executions({
  domain: "DomainName", # required
  start_time_filter: { # required
    oldest_date: Time.now, # required
    latest_date: Time.now,
  },
  type_filter: {
    name: "Name", # required
    version: "VersionOptional",
  },
  tag_filter: {
    tag: "Tag", # required
  },
  execution_filter: {
    workflow_id: "WorkflowId", # required
  },
})

Response structure


resp.count #=> Integer
resp.truncated #=> Boolean

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :domain (required, String)

    The name of the domain containing the workflow executions to count.

  • :start_time_filter (required, Types::ExecutionTimeFilter)

    Specifies the start time criteria that workflow executions must meet in order to be counted.

  • :type_filter (Types::WorkflowTypeFilter)

    Specifies the type of the workflow executions to be counted.

    <note markdown=“1”> executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request.

    </note>
    
  • :tag_filter (Types::TagFilter)

    If specified, only executions that have a tag that matches the filter are counted.

    <note markdown=“1”> executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request.

    </note>
    
  • :execution_filter (Types::WorkflowExecutionFilter)

    If specified, only workflow executions matching the WorkflowId in the filter are counted.

    <note markdown=“1”> executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request.

    </note>
    

Returns:



743
744
745
746
# File 'lib/aws-sdk-swf/client.rb', line 743

def count_open_workflow_executions(params = {}, options = {})
  req = build_request(:count_open_workflow_executions, params)
  req.send_request(options)
end