Method: Aws::SWF::Client#describe_workflow_type

Defined in:
lib/aws-sdk-swf/client.rb

#describe_workflow_type(params = {}) ⇒ Types::WorkflowTypeDetail

Returns information about the specified *workflow type*. This includes configuration settings specified when the type was registered and other information such as creation date, current status, etc.

**Access Control**

You can use IAM policies to control this action’s access to Amazon SWF resources as follows:

  • Use a Resource element with the domain name to limit the action to only specified domains.

  • Use an Action element to allow or deny permission to call this action.

  • Constrain the following parameters by using a Condition element with the appropriate keys.

    • workflowType.name: String constraint. The key is swf:workflowType.name.

    • workflowType.version: String constraint. The key is swf:workflowType.version.

If the caller doesn’t have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute’s cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF Workflows] in the *Amazon SWF Developer Guide*.

[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html

Examples:

Request syntax with placeholder values


resp = client.describe_workflow_type({
  domain: "DomainName", # required
  workflow_type: { # required
    name: "Name", # required
    version: "Version", # required
  },
})

Response structure


resp.type_info.workflow_type.name #=> String
resp.type_info.workflow_type.version #=> String
resp.type_info.status #=> String, one of "REGISTERED", "DEPRECATED"
resp.type_info.description #=> String
resp.type_info.creation_date #=> Time
resp.type_info.deprecation_date #=> Time
resp.configuration.default_task_start_to_close_timeout #=> String
resp.configuration.default_execution_start_to_close_timeout #=> String
resp.configuration.default_task_list.name #=> String
resp.configuration.default_task_priority #=> String
resp.configuration.default_child_policy #=> String, one of "TERMINATE", "REQUEST_CANCEL", "ABANDON"
resp.configuration.default_lambda_role #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :domain (required, String)

    The name of the domain in which this workflow type is registered.

  • :workflow_type (required, Types::WorkflowType)

    The workflow type to describe.

Returns:



1485
1486
1487
1488
# File 'lib/aws-sdk-swf/client.rb', line 1485

def describe_workflow_type(params = {}, options = {})
  req = build_request(:describe_workflow_type, params)
  req.send_request(options)
end