Method: Aws::SWF::Client#respond_decision_task_completed

Defined in:
lib/aws-sdk-swf/client.rb

#respond_decision_task_completed(params = {}) ⇒ Struct

Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed. The decisions argument specifies the list of decisions made while processing the task.

A DecisionTaskCompleted event is added to the workflow history. The executionContext specified is attached to the event in the workflow execution history.

**Access Control**

If an IAM policy grants permission to use RespondDecisionTaskCompleted, it can express permissions for the list of decisions in the decisions parameter. Each of the decisions has one or more parameters, much like a regular API call. To allow for policies to be as readable as possible, you can express permissions on decisions as if they were actual API calls, including applying conditions to some parameters. For more information, see [Using IAM to Manage Access to Amazon SWF Workflows] in the *Amazon SWF Developer Guide*.

[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html

Examples:

Request syntax with placeholder values


resp = client.respond_decision_task_completed({
  task_token: "TaskToken", # required
  decisions: [
    {
      decision_type: "ScheduleActivityTask", # required, accepts ScheduleActivityTask, RequestCancelActivityTask, CompleteWorkflowExecution, FailWorkflowExecution, CancelWorkflowExecution, ContinueAsNewWorkflowExecution, RecordMarker, StartTimer, CancelTimer, SignalExternalWorkflowExecution, RequestCancelExternalWorkflowExecution, StartChildWorkflowExecution, ScheduleLambdaFunction
      schedule_activity_task_decision_attributes: {
        activity_type: { # required
          name: "Name", # required
          version: "Version", # required
        },
        activity_id: "ActivityId", # required
        control: "Data",
        input: "Data",
        schedule_to_close_timeout: "DurationInSecondsOptional",
        task_list: {
          name: "Name", # required
        },
        task_priority: "TaskPriority",
        schedule_to_start_timeout: "DurationInSecondsOptional",
        start_to_close_timeout: "DurationInSecondsOptional",
        heartbeat_timeout: "DurationInSecondsOptional",
      },
      request_cancel_activity_task_decision_attributes: {
        activity_id: "ActivityId", # required
      },
      complete_workflow_execution_decision_attributes: {
        result: "Data",
      },
      fail_workflow_execution_decision_attributes: {
        reason: "FailureReason",
        details: "Data",
      },
      cancel_workflow_execution_decision_attributes: {
        details: "Data",
      },
      continue_as_new_workflow_execution_decision_attributes: {
        input: "Data",
        execution_start_to_close_timeout: "DurationInSecondsOptional",
        task_list: {
          name: "Name", # required
        },
        task_priority: "TaskPriority",
        task_start_to_close_timeout: "DurationInSecondsOptional",
        child_policy: "TERMINATE", # accepts TERMINATE, REQUEST_CANCEL, ABANDON
        tag_list: ["Tag"],
        workflow_type_version: "Version",
        lambda_role: "Arn",
      },
      record_marker_decision_attributes: {
        marker_name: "MarkerName", # required
        details: "Data",
      },
      start_timer_decision_attributes: {
        timer_id: "TimerId", # required
        control: "Data",
        start_to_fire_timeout: "DurationInSeconds", # required
      },
      cancel_timer_decision_attributes: {
        timer_id: "TimerId", # required
      },
      signal_external_workflow_execution_decision_attributes: {
        workflow_id: "WorkflowId", # required
        run_id: "WorkflowRunIdOptional",
        signal_name: "SignalName", # required
        input: "Data",
        control: "Data",
      },
      request_cancel_external_workflow_execution_decision_attributes: {
        workflow_id: "WorkflowId", # required
        run_id: "WorkflowRunIdOptional",
        control: "Data",
      },
      start_child_workflow_execution_decision_attributes: {
        workflow_type: { # required
          name: "Name", # required
          version: "Version", # required
        },
        workflow_id: "WorkflowId", # required
        control: "Data",
        input: "Data",
        execution_start_to_close_timeout: "DurationInSecondsOptional",
        task_list: {
          name: "Name", # required
        },
        task_priority: "TaskPriority",
        task_start_to_close_timeout: "DurationInSecondsOptional",
        child_policy: "TERMINATE", # accepts TERMINATE, REQUEST_CANCEL, ABANDON
        tag_list: ["Tag"],
        lambda_role: "Arn",
      },
      schedule_lambda_function_decision_attributes: {
        id: "FunctionId", # required
        name: "FunctionName", # required
        control: "Data",
        input: "FunctionInput",
        start_to_close_timeout: "DurationInSecondsOptional",
      },
    },
  ],
  execution_context: "Data",
  task_list: {
    name: "Name", # required
  },
  task_list_schedule_to_start_timeout: "DurationInSecondsOptional",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :task_token (required, String)

    The taskToken from the DecisionTask.

    taskToken is generated by the service and should be treated as an opaque value. If the task is passed to another process, its taskToken must also be passed. This enables it to provide its progress and respond with results.

  • :decisions (Array<Types::Decision>)

    The list of decisions (possibly empty) made by the decider while processing this decision task. See the docs for the Decision structure for details.

  • :execution_context (String)

    User defined context to add to workflow execution.

  • :task_list (Types::TaskList)

    The task list to use for the future decision tasks of this workflow execution. This list overrides the original task list you specified while starting the workflow execution.

  • :task_list_schedule_to_start_timeout (String)

    Specifies a timeout (in seconds) for the task list override. When this parameter is missing, the task list override is permanent. This parameter makes it possible to temporarily override the task list. If a decision task scheduled on the override task list is not started within the timeout, the decision task will time out. Amazon SWF will revert the override and schedule a new decision task to the original task list.

    If a decision task scheduled on the override task list is started within the timeout, but not completed within the start-to-close timeout, Amazon SWF will also revert the override and schedule a new decision task to the original task list.

Returns:

  • (Struct)

    Returns an empty response.



3926
3927
3928
3929
# File 'lib/aws-sdk-swf/client.rb', line 3926

def respond_decision_task_completed(params = {}, options = {})
  req = build_request(:respond_decision_task_completed, params)
  req.send_request(options)
end