Class: Aws::SWF::Types::GetWorkflowExecutionHistoryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SWF::Types::GetWorkflowExecutionHistoryInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-swf/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain ⇒ String
The name of the domain containing the workflow execution.
-
#execution ⇒ Types::WorkflowExecution
Specifies the workflow execution for which to return the history.
-
#maximum_page_size ⇒ Integer
The maximum number of results that are returned per call.
-
#next_page_token ⇒ String
If
NextPageTokenis returned there are more results available. -
#reverse_order ⇒ Boolean
When set to
true, returns the events in reverse order.
Instance Attribute Details
#domain ⇒ String
The name of the domain containing the workflow execution.
2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-swf/types.rb', line 2214 class GetWorkflowExecutionHistoryInput < Struct.new( :domain, :execution, :next_page_token, :maximum_page_size, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#execution ⇒ Types::WorkflowExecution
Specifies the workflow execution for which to return the history.
2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-swf/types.rb', line 2214 class GetWorkflowExecutionHistoryInput < Struct.new( :domain, :execution, :next_page_token, :maximum_page_size, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#maximum_page_size ⇒ Integer
The maximum number of results that are returned per call. Use nextPageToken to obtain further pages of results.
2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-swf/types.rb', line 2214 class GetWorkflowExecutionHistoryInput < Struct.new( :domain, :execution, :next_page_token, :maximum_page_size, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
If NextPageToken is returned there are more results available. The value of NextPageToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return a 400 error: “‘Specified token has exceeded its maximum lifetime`”.
The configured maximumPageSize determines how many results can be returned in a single call.
2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-swf/types.rb', line 2214 class GetWorkflowExecutionHistoryInput < Struct.new( :domain, :execution, :next_page_token, :maximum_page_size, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#reverse_order ⇒ Boolean
When set to true, returns the events in reverse order. By default the results are returned in ascending order of the eventTimeStamp of the events.
2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/aws-sdk-swf/types.rb', line 2214 class GetWorkflowExecutionHistoryInput < Struct.new( :domain, :execution, :next_page_token, :maximum_page_size, :reverse_order) SENSITIVE = [] include Aws::Structure end |