Method: Aws::SWF::Types::WorkflowExecutionConfiguration#child_policy

Defined in:
lib/aws-sdk-swf/types.rb

#child_policyString

The policy to use for the child workflow executions if this workflow execution is terminated, by calling the TerminateWorkflowExecution action explicitly or due to an expired timeout.

The supported child policies are:

  • TERMINATE – The child executions are terminated.

  • REQUEST_CANCEL – A request to cancel is attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event.

  • ABANDON – No action is taken. The child executions continue to run.

Returns:

  • (String)


5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
# File 'lib/aws-sdk-swf/types.rb', line 5865

class WorkflowExecutionConfiguration < Struct.new(
  :task_start_to_close_timeout,
  :execution_start_to_close_timeout,
  :task_list,
  :task_priority,
  :child_policy,
  :lambda_role)
  SENSITIVE = []
  include Aws::Structure
end