Class: Aws::SWF::Types::WorkflowExecutionInfos
- Inherits:
-
Struct
- Object
- Struct
- Aws::SWF::Types::WorkflowExecutionInfos
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-swf/types.rb
Overview
Contains a paginated list of information about workflow executions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_infos ⇒ Array<Types::WorkflowExecutionInfo>
The list of workflow information structures.
-
#next_page_token ⇒ String
If a
NextPageTokenwas returned by a previous call, there are more results available.
Instance Attribute Details
#execution_infos ⇒ Array<Types::WorkflowExecutionInfo>
The list of workflow information structures.
6157 6158 6159 6160 6161 6162 |
# File 'lib/aws-sdk-swf/types.rb', line 6157 class WorkflowExecutionInfos < Struct.new( :execution_infos, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
If a NextPageToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in nextPageToken. Keep all other arguments unchanged.
The configured maximumPageSize determines how many results can be returned in a single call.
6157 6158 6159 6160 6161 6162 |
# File 'lib/aws-sdk-swf/types.rb', line 6157 class WorkflowExecutionInfos < Struct.new( :execution_infos, :next_page_token) SENSITIVE = [] include Aws::Structure end |