Method: Aws::SWF::Types::WorkflowTypeConfiguration#default_task_priority
- Defined in:
- lib/aws-sdk-swf/types.rb
#default_task_priority ⇒ String
The default task priority, specified when registering the workflow type, for all decision tasks of this workflow type. This default can be overridden when starting a workflow execution using the StartWorkflowExecution action or the StartChildWorkflowExecution decision.
Valid values are integers that range from Java’s Integer.MIN_VALUE (-2147483648) to Integer.MAX_VALUE (2147483647). Higher numbers indicate higher priority.
For more information about setting task priority, see [Setting Task Priority] in the *Amazon SWF Developer Guide*.
[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/programming-priority.html
7321 7322 7323 7324 7325 7326 7327 7328 7329 7330 |
# File 'lib/aws-sdk-swf/types.rb', line 7321 class WorkflowTypeConfiguration < Struct.new( :default_task_start_to_close_timeout, :default_execution_start_to_close_timeout, :default_task_list, :default_task_priority, :default_child_policy, :default_lambda_role) SENSITIVE = [] include Aws::Structure end |