Method: Aws::SWF::Client#describe_workflow_type
- Defined in:
- lib/aws-sdk-swf/client.rb
#describe_workflow_type(params = {}) ⇒ Types::WorkflowTypeDetail
Returns information about the specified *workflow type*. This includes configuration settings specified when the type was registered and other information such as creation date, current status, etc.
**Access Control**
You can use IAM policies to control this action’s access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys.-
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
-
If the caller doesn’t have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute’s cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF Workflows] in the *Amazon SWF Developer Guide*.
[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html
1485 1486 1487 1488 |
# File 'lib/aws-sdk-swf/client.rb', line 1485 def describe_workflow_type(params = {}, = {}) req = build_request(:describe_workflow_type, params) req.send_request() end |