Method: Aws::SWF::Client#respond_decision_task_completed
- Defined in:
- lib/aws-sdk-swf/client.rb
#respond_decision_task_completed(params = {}) ⇒ Struct
Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed. The decisions argument specifies the list of decisions made while processing the task.
A DecisionTaskCompleted event is added to the workflow history. The executionContext specified is attached to the event in the workflow execution history.
**Access Control**
If an IAM policy grants permission to use RespondDecisionTaskCompleted, it can express permissions for the list of decisions in the decisions parameter. Each of the decisions has one or more parameters, much like a regular API call. To allow for policies to be as readable as possible, you can express permissions on decisions as if they were actual API calls, including applying conditions to some parameters. For more information, see [Using IAM to Manage Access to Amazon SWF Workflows] in the *Amazon SWF Developer Guide*.
[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html
3926 3927 3928 3929 |
# File 'lib/aws-sdk-swf/client.rb', line 3926 def respond_decision_task_completed(params = {}, = {}) req = build_request(:respond_decision_task_completed, params) req.send_request() end |