Method: Aws::SWF::Client#undeprecate_workflow_type
- Defined in:
- lib/aws-sdk-swf/client.rb
#undeprecate_workflow_type(params = {}) ⇒ Struct
Undeprecates a previously deprecated *workflow type*. After a workflow type has been undeprecated, you can create new executions of that type.
<note markdown=“1”> This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.
</note>
**Access Control**
You can use IAM policies to control this action’s access to Amazon SWF resources as follows:
-
Use a
Resourceelement with the domain name to limit the action to only specified domains. -
Use an
Actionelement to allow or deny permission to call this action. -
Constrain the following parameters by using a
Conditionelement with the appropriate keys.-
workflowType.name: String constraint. The key isswf:workflowType.name. -
workflowType.version: String constraint. The key isswf:workflowType.version.
-
If the caller doesn’t have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute’s cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF Workflows] in the *Amazon SWF Developer Guide*.
[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html
4551 4552 4553 4554 |
# File 'lib/aws-sdk-swf/client.rb', line 4551 def undeprecate_workflow_type(params = {}, = {}) req = build_request(:undeprecate_workflow_type, params) req.send_request() end |