Method: Aws::SWF::Types::WorkflowExecutionConfiguration#task_priority
- Defined in:
- lib/aws-sdk-swf/types.rb
#task_priority ⇒ String
The priority assigned to decision tasks for this workflow execution. Valid values are integers that range from Java’s Integer.MIN_VALUE (-2147483648) to Integer.MAX_VALUE (2147483647). Higher numbers indicate higher priority.
For more information about setting task priority, see [Setting Task Priority][1] in the *Amazon SWF Developer Guide*.
[1]: docs.aws.amazon.com/amazonswf/latest/developerguide/programming-priority.html
5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-swf/types.rb', line 5865 class WorkflowExecutionConfiguration < Struct.new( :task_start_to_close_timeout, :execution_start_to_close_timeout, :task_list, :task_priority, :child_policy, :lambda_role) SENSITIVE = [] include Aws::Structure end |